@@ -2,7 +2,11 @@ use serde::{Deserialize, Serialize};
 use swc_css_ast::*;
 use swc_css_visit::{Visit, VisitWith};
 
-use crate::rule::{visitor_rule, LintRule, LintRuleContext};
+use crate::{
+    pattern::NamePattern,
+    rule::{visitor_rule, LintRule, LintRuleContext},
+    ConfigError,
+};
 
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 #[serde(rename_all = "camelCase")]
@@ -10,15 +14,27 @@ pub struct AtRuleNoUnknownConfig {
     ignore_at_rules: Option<Vec<String>>,
 }
 
-pub fn at_rule_no_unknown(ctx: LintRuleContext<AtRuleNoUnknownConfig>) -> Box<dyn LintRule> {
-    let ignored = ctx.config().ignore_at_rules.clone().unwrap_or_default();
-    visitor_rule(ctx.reaction(), AtRuleNoUnknown { ctx, ignored })
+pub fn at_rule_no_unknown(
+    ctx: LintRuleContext<AtRuleNoUnknownConfig>,
+) -> Result<Box<dyn LintRule>, ConfigError> {
+    let ignored = ctx
+        .config()
+        .ignore_at_rules
+        .clone()
+        .unwrap_or_default()
+        .into_iter()
+        .map(NamePattern::try_from)
+        .collect::<Result<_, _>>()?;
+    Ok(visitor_rule(
+        ctx.reaction(),
+        AtRuleNoUnknown { ctx, ignored },
+    ))
 }
 
 #[derive(Debug, Default)]
 struct AtRuleNoUnknown {
     ctx: LintRuleContext<AtRuleNoUnknownConfig>,
-    ignored: Vec<String>,
+    ignored: Vec<NamePattern>,
 }
 
 impl Visit for AtRuleNoUnknown {
@@ -28,7 +44,7 @@ impl Visit for AtRuleNoUnknown {
             AtRuleName::Ident(ident) => &ident.value,
         };
 
-        if self.ignored.iter().all(|item| name != item) {
+        if self.ignored.iter().all(|item| !item.is_match(name)) {
             let message = format!("Unexpected unknown at-rule \"@{}\".", name);
             self.ctx.report(&unknown_at_rule.name, message);
         }
